/*
 * FileIO.h
 *
 * Copyright (C) 1999 Karim Yaghmour.
 *
 * This is distributed under GPL.
 *
 * Header for File I/O engine.
 *
 * History : 
 *    K.Y., 26/06/99, Initial typing.
 *
 * Note : The current version of this decoder is for linux 2.2.0.
 */

#ifndef __TRACE_TOOLKIT_FILE_IO__
#define __TRACE_TOOLKIT_FILE_IO__

#include "TraceToolkit.h"

/* Definitions */
#define HEADER_BANER  "####################################################################\n"
#define HEADER_CPUID  "CPU-ID"
#define HEADER_EVENT  "Event"
#define HEADER_TIME   "\t\tTime(sec, usec)\t"
#define HEADER_PID    "\tPID"
#define HEADER_LENGTH "\tLength"
#define HEADER_STRING "\tDescription"

/* Functions */
int  ReadRawEntry
       (int              /* The file to read from */,
	traceProperties* /* The properties of the trace being read */,
	int*             /* The event ID read */,
	struct timeval*  /* The time of occurence of the event */,
	int*             /* The CPU ID */,
	void**           /* The description structure */,
	char**           /* The description string */,
	int*             /* The size of the entry */);
void PrintHeader
       (int              /* The file to which header is to be printed */,
	traceProperties* /* The properties of the trace for which header is printed */,
	options*         /* The options of output */);
void PrintEvent
       (int              /* The file to which an event is to be printed */,
	int              /* The CPU-ID of the cpu on which event took place */,
	int              /* The event's ID */,
	struct timeval*  /* The time of the occuring event */,
	int              /* The PID of the process to which this event belongs */,
	int              /* The size of the data entry */,
	char*            /* The description string */,
	traceProperties* /* The properties of the trace to which this event belongs */,
	options*         /* The output options */);
void DumpToOutput
       (int              /* Input file */,
	int              /* Output file */,
	options*         /* The output options */);

/******************************************************************
 * Macro :
 *    PrintData()
 * Description :
 *    Prints out the given data in the given format to the given file.
 * Parameters :
 *    pmFile, File to which we write.
 *    pmFormat, Format of the data.
 *    pmArg, The data to be printed
 * History :
 *    K.Y., 17/10/99, Initial typing
 ******************************************************************/
#define PrintData(pmFile, pmFormat, pmArg...) \
{\
  char         lWriteString[100];\
\
  sprintf(lWriteString, pmFormat, ##pmArg);\
  write(pmFile, lWriteString, strlen(lWriteString));\
}

#endif /* __TRACE_TOOLKIT_FILE_IO__ */
